%% "The Alibaba Effect: Spatial Consumption Inequality and Welfare Gains from E-commerce,"
% Fan, Tang, Zhu and Zou 2018
% This program produces Table 6, Table 7 and Figure 1 of the paper.
%% House Keeping: Managing Directory Paths
restoredefaultpath;
currentpath=pwd;
datapath=fullfile(currentpath,'Data');
estimatepath=fullfile(currentpath,'Estimates');
initialvaluepath=fullfile(currentpath,'InitialValues');
addpath(datapath); 
addpath(estimatepath);
addpath(initialvaluepath);
%% Setting Parameter Values
%Load Data
load 'L.mat';
load 'SameProv.mat';
load 'data_service_share.mat';
load 'ProvGroup.mat';
load 'phi_min_v0.mat'
load 'BilateralDistance.mat';

% Key Parameters
N=320    ; %Number of regions
H=2      ; %Number of sectors; h=1 is the nontradeable sector.
sigma=[5,5];
theta=[6,6]; 
beta=[data_service_share,(1-data_service_share)];
alpha=1.3*(sigma-1); % Pareto Shape parameter.
EntryCost=14.286;
kappa=gamma((theta+1-sigma)/theta).*(sigma./(sigma-1)).^(1-sigma); % Kappa is the constant defined in the text. Notice that gamma is a Matlab built-in function  
NProv=max(ProvGroup);    
MainParameters=Func_v2struct(N, NProv, ProvGroup,SameProv, L, H, beta, sigma, theta, kappa, alpha, phi_min, EntryCost);
parameter_file=fullfile(currentpath,'Data','MainParameters.mat');
save(parameter_file,'MainParameters')

%% Stepsize and Convergence Criteria. 
StepsizeWage=0.2;
StepsizeP=0.5;
StepsizeM=0.15;
ToleranceExcessProfit=1e-6;
ToleranceL=1e-6;
ToleranceP=1e-5;
Max_P_Iter=30000;

FirmMass_ini=beta.*[L,L]/40;
w_autarky=ones(N,1); 
P_power_autarky=-((ones(N,1)*(kappa.*alpha)).*phi_min.^(ones(N,1)*(sigma-1))./(ones(N,1)*(sigma-alpha-1))).*(FirmMass_ini.*(w_autarky*ones(1,H)).^(ones(N,1)*(1-sigma))); %From zero profit condition
w_ini=w_autarky;
P_power_ini=P_power_autarky;

MainOptions=Func_v2struct(ToleranceExcessProfit, ToleranceL, ToleranceP,StepsizeWage,StepsizeP,StepsizeM,Max_P_Iter,w_ini,P_power_ini,FirmMass_ini);
option_file=fullfile(currentpath,'Data','MainOptions.mat');
save(option_file,'MainOptions')

%% Target Moments from the data
DataAverageFirmSize=80;
DataExporterPercentage2002=0.94; 
DataProvAbsorptionRatio2013=0.54;
DataProvAbsorptionRatioOnline2013=0.145; 
DataOfflineElasticity2002=-1.40; 
DataOnlineElasticity2013=-0.47; 
DataCoef_L_OnlineShare2013=-0.11;
DataCoef_MP_OnlineShare2013=-0.19;
DataOnlineShare2013=0.080;
CalibrationTargets=Func_v2struct(DataAverageFirmSize,DataExporterPercentage2002,DataProvAbsorptionRatio2013,DataProvAbsorptionRatioOnline2013,...
    DataOfflineElasticity2002,DataOnlineElasticity2013,DataCoef_L_OnlineShare2013,DataCoef_MP_OnlineShare2013,DataOnlineShare2013);
CalibrationTargets_file=fullfile(currentpath,'Data','CalibrationTargets.mat');
save(CalibrationTargets_file,'CalibrationTargets')

%% Calibration
CostVec_ini=[-2.5815    -0.23339     0.06991     0.20524     0.89877     0.28758      0.1013]; %Initial Value
tstart=tic; 
options = optimset('Display','iter','MaxFunEvals',2000,'MaxIter',2000);
[Cost_Vector,~,ExitFlagStep1] = fminsearch(@Func_SolvingTwoEqm, CostVec_ini,options);
TimeTaken=toc(tstart)/60;
disp([' Time Taken  : ', num2str(floor(TimeTaken/60)), ' hours and ', num2str(mod(TimeTaken,60)), ' minutes.']);
calibrated_parameters_file=fullfile(currentpath,'Estimates','calibrated_parameters.mat');
save(calibrated_parameters_file,'Cost_Vector');
%% Tables
load 'calibrated_parameters.mat';
FixedCost=exp(Cost_Vector(1))*[1,1];
Coef_0_P=Cost_Vector(2);
Coef_L_P=Cost_Vector(3);
Coef_Distance_P=Cost_Vector(4);
Coef_0_E=Cost_Vector(5);
Coef_DifCity_E=Cost_Vector(6);
Coef_Distance_E=Cost_Vector(7);

delta0=0;
delta1=Coef_0_P+Coef_Distance_P*log(100); % Normalization by which we measure bilateral distance in unit of 100 kms.
delta2=Coef_Distance_P;
deltaL=Coef_L_P;
gamma0=Coef_0_E;
gamma1=Coef_0_E+Coef_DifCity_E+Coef_Distance_E*log(100);  % Normalization by which we measure bilateral distance in unit of 100 kms.
gamma2=Coef_Distance_E;

% Table 6
disp('------------------------------------------------------------------------------------------')
disp(' Table 6 ')
disp(['     elasticity of substitution (\sigma)=            ',num2str(sigma(1))])
disp(['     dispersion of consumer preference (\theta)=     ',num2str(theta(1))])
disp(['     Pareto shape of productivity=                   ',num2str(alpha(1))])
disp('------------------------------------------------------------------------------------------')

%Table 7
disp('------------------------------------------------------------------------------------------')
disp(' Table 7 ')
disp(['     entry cost=     ',num2str(EntryCost(1))])
disp(['     fixed cost=     ',num2str(FixedCost(1))])
disp(['        delta_0=     ',num2str(delta0)])
disp(['        delta_1=     ',num2str(delta1)])
disp(['        delta_2=     ',num2str(delta2)])
disp(['        delta_L=     ',num2str(deltaL)])
disp(['        gamma_0=     ',num2str(gamma0)])
disp(['        gamma_1=     ',num2str(gamma1)])
disp(['        gamma_2=     ',num2str(gamma2)])
disp('------------------------------------------------------------------------------------------')
%% Section 5.3: Calibrated Online and Offline Shipping Costs
BilateralDistance=reshape(BilateralDistance,N*N,1);
SortedBilateralDistance=sort(BilateralDistance);
sorted_tau_P=exp(Coef_0_P+Coef_L_P*log(mean(L)/min(L))+Coef_Distance_P*log(SortedBilateralDistance));
sorted_tau_E=exp(Coef_0_E+Coef_DifCity_E+Coef_Distance_E*log(SortedBilateralDistance));

% Figure 1
figure;
hold on
h1=plot(log(SortedBilateralDistance), log(sorted_tau_E),'-r');
h2=plot(log(SortedBilateralDistance), log(sorted_tau_P),'-.b');
hold off
xlabel('log bilateral distance')
ylabel('log shipping cost')
set(h1(1),'linewidth',1);
set(h2(1),'linewidth',2);
xlim([5 8.5])
ylim([0.5 2.5])
legend('online','offline')
saveas(gcf,'Figures/Figure1.png','png')

% END