%% "The Alibaba Effect: Spatial Consumption Inequality and Welfare Gains from E-commerce,"
% Fan, Tang, Zhu and Zou 2018
% This program produces the main data needed for Table 8. This program also prints the second row of Table 8. 
% Use the output from this program for the STATA program Stata_program_validation which produces Table 8, Figure D1 and Table D5.
%% House Keeping: Managing Directory Paths
restoredefaultpath;
currentpath=pwd;
datapath=fullfile(currentpath,'Data');
estimatepath=fullfile(currentpath,'Estimates');
initialvaluepath=fullfile(currentpath,'InitialValues');
addpath(datapath);
addpath(estimatepath);
addpath(initialvaluepath);
%% Setting Parameter Values
%Load Data
load 'L.mat';
load 'SameProv.mat';
load 'data_service_share.mat';
load 'ProvGroup.mat';
load 'phi_min_v0.mat'
load 'BilateralDistance.mat';
load 'BigCityList.mat' % This vector indicates the big cities covered by Feenstra et al. 2016.
load 'MainOptions.mat'

% Key Parameters
N=320    ; %Number of regions
H=2      ; %Number of sectors; h=1 is the nontradeable sector.
sigma=[5,5];
theta=[6,6]; 
beta=[data_service_share,(1-data_service_share)];
alpha=1.3*(sigma-1); % Pareto Shape parameter.
EntryCost=14.286;
kappa=gamma((theta+1-sigma)/theta).*(sigma./(sigma-1)).^(1-sigma); % Kappa is the constant defined in the text. Notice that gamma is a Matlab built-in function  
NProv=max(ProvGroup);    
MainParameters=Func_v2struct(N, NProv, ProvGroup,SameProv, L, H, beta, sigma, theta, kappa, alpha, phi_min, EntryCost);
parameter_file=fullfile(currentpath,'Data','MainParameters.mat');
save(parameter_file,'MainParameters')

[N, NProv, ProvGroup,SameProv, L, H, beta, sigma, theta, kappa, alpha, phi_min, EntryCost]=Func_v2struct(MainParameters);
%% Loading Trade Costs and EComm Costs Estimates
load 'calibrated_parameters';
cost_vec=Cost_Vector;
FixedCost=exp(cost_vec(1));
Coef_0_P=cost_vec(2);
Coef_L_P=cost_vec(3);
Coef_Distance_P=cost_vec(4);
Coef_0_E=cost_vec(5);
Coef_DifCity_E=cost_vec(6);
Coef_Distance_E=cost_vec(7);

%trade cost for offline trade 
log_tau_P=Coef_0_P*(ones(N,N)-eye(N))+Coef_L_P*(ones(N,1)*log(L/min(L))')+Coef_Distance_P*log(BilateralDistance);
tau_P=exp(log_tau_P);
tau_P=max(tau_P, 1);

%trade cost for online trade 
tau_E_2002=exp(50)*ones(N,N); % Setting E-Commerce Cost to be very high.
MyTradeCosts2002=Func_v2struct(tau_E_2002, tau_P, FixedCost);

log_tau_E_2013=Coef_0_E+(ones(N,N)-eye(N))*Coef_DifCity_E+Coef_Distance_E*log(BilateralDistance);
tau_E_2013=exp(log_tau_E_2013);
tau_E_2013=max(tau_E_2013,1);
MyTradeCosts2013=Func_v2struct(tau_E_2013, tau_P, FixedCost);
%% Solving the model with the different e-Commerce levels.
disp('-----------------------------' )
disp('  Economy without ECommerce  ' )
NoECommEqm=Func_Solve_The_Model_v0(MainParameters,MyTradeCosts2002,MainOptions);
disp('-----------------------------' )
disp('  Economy with ECommerce     ' )
ECommEqm=Func_Solve_The_Model_v0(MainParameters,MyTradeCosts2013,MainOptions);



%% Comparing the implied living cost to Feenstra et al (2017)
PriceIndex2002=NoECommEqm.PriceIndex/NoECommEqm.PriceIndex(73); % Normalizing the price in Shanghai to be one
PriceIndex2013=ECommEqm.PriceIndex/NoECommEqm.PriceIndex(73); % Normalizing  the price in Shanghai to be one

BigCityL=L(BigCityList);  % Cities used in Feenstra et al. 2017
BigCityPriceIndex2002=PriceIndex2002(BigCityList);

% The following should be compared to  -0.13 in Feenstra et al 2017
Coef_PriceIndex2002_BigCity=regress(BigCityPriceIndex2002,[ones(sum(BigCityList),1),log(BigCityL)]);
Coef_L_2002=Coef_PriceIndex2002_BigCity(2);

% Table 8
disp('------------------------------------------------------------------------------------------')
disp(' Second row of Table 8')
disp('                                                 Data      Model               ')
disp(['   slope of price index against log population   -0.13  ', num2str(Coef_L_2002)])

%%  Aggregating Variables at Provincial Level
MP1=(1./BilateralDistance)*L-(L./diag(BilateralDistance)); %Measure of Market Potential
ProvPop=NaN(NProv,1);
ProvMP=NaN(NProv,1);
ModelFirmMass2002=NaN(NProv,1);
ModelFirmMass2013=NaN(NProv,1);

for i=1:NProv
    ProvPop(i)=(ProvGroup==i)'*L;
    ModelFirmMass2002(i)=(ProvGroup==i)'*NoECommEqm.FirmMass(:,2);
    ModelFirmMass2013(i)=(ProvGroup==i)'*ECommEqm.FirmMass(:,2);
    ProvMP(i)=(ProvGroup==i)'*MP1; % MP Potential of a Province
end

ModelOfflineAbsorption=ECommEqm.OfflineAbsorptionRatio_by_Province;
ModelOnlineAbsorption=ECommEqm.OnlineAbsorptionRatio_by_Province;
ModelOnlineShare=ECommEqm.OnlineShare_by_Province;

Prov_Group=(1:NProv)';
DataTable=table(Prov_Group, ProvPop, ProvMP,ModelFirmMass2002, ModelFirmMass2013,ModelOfflineAbsorption,ModelOnlineAbsorption);
writetable(DataTable,'ExternalValidation/ProvValidationData.csv','Delimiter',',')

% END