%% "The Alibaba Effect: Spatial Consumption Inequality and Welfare Gains from E-commerce,"
% Fan, Tang, Zhu and Zou 2018
% This program  produces Table 9, Figure 2, Figure 5 and Figure 6.  It also produces the data for Table 10.
% Use the data output from this program for the STATA program Stata_program_spatial_inequality which produces Table 10,
%% House Keeping: Managing Directory Paths
restoredefaultpath;
currentpath=pwd;
datapath=fullfile(currentpath,'Data');
estimatepath=fullfile(currentpath,'Estimates');
initialvaluepath=fullfile(currentpath,'InitialValues');
addpath(datapath);
addpath(estimatepath);
addpath(initialvaluepath);
%% Setting Parameter Values
%Load Data
load 'L.mat';
load 'SameProv.mat';
load 'data_service_share.mat';
load 'ProvGroup.mat';
load 'phi_min_v0.mat'
load 'BilateralDistance.mat';
load 'MainOptions.mat'

% Key Parameters
N=320    ; %Number of regions
H=2      ; %Number of sectors; h=1 is the nontradeable sector.
sigma=[5,5];
theta=[6,6]; 
beta=[data_service_share,(1-data_service_share)];
alpha=1.3*(sigma-1); % Pareto Shape parameter.
EntryCost=14.286;
kappa=gamma((theta+1-sigma)/theta).*(sigma./(sigma-1)).^(1-sigma); % Kappa is the constant defined in the text. Notice that gamma is a Matlab built-in function  
NProv=max(ProvGroup);    
MainParameters=Func_v2struct(N, NProv, ProvGroup,SameProv, L, H, beta, sigma, theta, kappa, alpha, phi_min, EntryCost);
parameter_file=fullfile(currentpath,'Data','MainParameters.mat');
save(parameter_file,'MainParameters')
[N, NProv, ProvGroup,SameProv, L, H, beta, sigma, theta, kappa, alpha, phi_min, EntryCost]=Func_v2struct(MainParameters);
%% Loading Trade Costs and EComm Costs Estimates
load 'calibrated_parameters.mat';
cost_vec=Cost_Vector;
FixedCost=exp(cost_vec(1));
Coef_0_P=cost_vec(2);
Coef_L_P=cost_vec(3);
Coef_Distance_P=cost_vec(4);
Coef_0_E=cost_vec(5);
Coef_DifCity_E=cost_vec(6);
Coef_Distance_E=cost_vec(7);

log_tau_P=Coef_0_P*(ones(N,N)-eye(N))+Coef_L_P*(ones(N,1)*log(L/min(L))')+Coef_Distance_P*log(BilateralDistance);
tau_P=exp(log_tau_P);
tau_P=max(tau_P, 1);

tau_E_2002=exp(50)*ones(N,N); % Setting E-Commerce Cost to be very high.
MyTradeCosts2002=Func_v2struct(tau_E_2002, tau_P, FixedCost);
log_tau_E_2013=Coef_0_E+(ones(N,N)-eye(N))*Coef_DifCity_E+Coef_Distance_E*log(BilateralDistance);
tau_E_2013=exp(log_tau_E_2013);
tau_E_2013=max(tau_E_2013,1);
MyTradeCosts2013=Func_v2struct(tau_E_2013, tau_P, FixedCost);
%% Solving the model without and with e-Commerce
disp('-----------------------------' )
disp('  Economy without ECommerce  ' )
NoECommEqm=Func_Solve_The_Model_v0(MainParameters,MyTradeCosts2002,MainOptions);
disp('-----------------------------' )
disp('  Economy with ECommerce     ' )
ECommEqm=Func_Solve_The_Model_v0(MainParameters,MyTradeCosts2013,MainOptions);
%% Section 5.5: Spatial Consumption Inequality before E-Commerce
NormalizedRealWage2002=NoECommEqm.RealWage/NoECommEqm.RealWage(73); % Normalizing the real wage in Shanghai to be one
NormalizedPriceIndex2002=NoECommEqm.PriceIndex/NoECommEqm.PriceIndex(73); % Normalizing the price in Shanghai to be one
MarketPotential=(1./BilateralDistance)*L-(L./diag(BilateralDistance)); %Measure of Market Potential

%Figure 2a
figure;
hold on
scatter(log(L),NormalizedRealWage2002, 20,'o','filled')
scatter(log(L),NormalizedPriceIndex2002)
hlines = lsline;
set(hlines(1), 'Color', 'r','linewidth',1)
set(hlines(2), 'Color', 'b','linewidth',1)
legend('Real Wage','Price Index')
hold off
xlim([12,17.5])
xticks(12:1:17)
xlabel('log population')
ylabel('Real Wage and Price Index ') 
saveas(gcf,'Figures/Figure2a.png','png')

%Figure 2b
figure;
hold on
scatter(log(MarketPotential),NormalizedRealWage2002, 20,'o','filled')
scatter(log(MarketPotential),NormalizedPriceIndex2002,20)
hlines = lsline;
set(hlines(1), 'Color', 'r','linewidth',1)
set(hlines(2), 'Color', 'b','linewidth',1)
legend('Real Wage','Price Index')
hold off
xlabel('log market potential')
ylabel('% Real Wage and Price Index ') 
saveas(gcf,'Figures/Figure2b.png','png')

%% Section 5.6: The Effects of e-Commerce on Domestic Trade and Welfare
RealWage_by_size_quintile_M=Func_Summarize_By_Groups(NoECommEqm.RealWage,MarketPotential); %summarize
norm_RealWage_M=RealWage_by_size_quintile_M(1); %getting a number for the normalization. 
RealWage_by_size_quintile_L=Func_Summarize_By_Groups(NoECommEqm.RealWage,L); %summarize
norm_RealWage_L=RealWage_by_size_quintile_L(1); %getting a number for the normalization. 

% No E
summary_OnlineShare_NoE_L=Func_Summarize_By_Groups(NoECommEqm.OnlineShare_by_City,L);
summary_ImportRatio_NoE_L=Func_Summarize_By_Groups(NoECommEqm.ImportRatio,L);
summary_ImportRatioOnline_NoE_L=Func_Summarize_By_Groups(NoECommEqm.ImportRatioOnline,L);
summary_ImportRatioOffline_NoE_L=Func_Summarize_By_Groups(NoECommEqm.ImportRatioOffline,L);
summary_RealWage_NoE_L=Func_Summarize_By_Groups(NoECommEqm.RealWage/norm_RealWage_L,L);
summary_OfflineVariety_NoE_L=Func_Summarize_By_Groups(NoECommEqm.OfflineVariety/min(NoECommEqm.OfflineVariety),L);

summary_OnlineShare_NoE_M=Func_Summarize_By_Groups(NoECommEqm.OnlineShare_by_City,MarketPotential);
summary_ImportRatio_NoE_M=Func_Summarize_By_Groups(NoECommEqm.ImportRatio,MarketPotential);
summary_ImportRatioOnline_NoE_M=Func_Summarize_By_Groups(NoECommEqm.ImportRatioOnline,MarketPotential);
summary_ImportRatioOffline_NoE_M=Func_Summarize_By_Groups(NoECommEqm.ImportRatioOffline,MarketPotential);
summary_RealWage_NoE_M=Func_Summarize_By_Groups(NoECommEqm.RealWage/norm_RealWage_M,MarketPotential);
summary_OfflineVariety_NoE_M=Func_Summarize_By_Groups(NoECommEqm.OfflineVariety/min(NoECommEqm.OfflineVariety),MarketPotential);

% E
summary_OnlineShare_E_L=Func_Summarize_By_Groups(ECommEqm.OnlineShare_by_City,L);
summary_ImportRatio_E_L=Func_Summarize_By_Groups(ECommEqm.ImportRatio,L);
summary_ImportRatioOnline_E_L=Func_Summarize_By_Groups(ECommEqm.ImportRatioOnline,L);
summary_ImportRatioOffline_E_L=Func_Summarize_By_Groups(ECommEqm.ImportRatioOffline,L);
summary_RealWage_E_L=Func_Summarize_By_Groups(ECommEqm.RealWage/norm_RealWage_L,L);

summary_OnlineShare_E_M=Func_Summarize_By_Groups(ECommEqm.OnlineShare_by_City,MarketPotential);
summary_ImportRatio_E_M=Func_Summarize_By_Groups(ECommEqm.ImportRatio,MarketPotential);
summary_ImportRatioOnline_E_M=Func_Summarize_By_Groups(ECommEqm.ImportRatioOnline,MarketPotential);
summary_ImportRatioOffline_E_M=Func_Summarize_By_Groups(ECommEqm.ImportRatioOffline,MarketPotential);
summary_RealWage_E_M=Func_Summarize_By_Groups(ECommEqm.RealWage/norm_RealWage_M,MarketPotential);

% Changes
%NoE to E
% By Population
summary_Change_OnlineShare_E_L=summary_OnlineShare_E_L-summary_OnlineShare_NoE_L;
summary_Change_ImportRatio_E_L=summary_ImportRatio_E_L-summary_ImportRatio_NoE_L;
summary_Change_ImportRatioOnline_E_L=summary_ImportRatioOnline_E_L-summary_ImportRatioOnline_NoE_L;
summary_Change_ImportRatioOffline_E_L=summary_ImportRatioOffline_E_L-summary_ImportRatioOffline_NoE_L;
summary_Change_RealWage_E_L=log(summary_RealWage_E_L)-log(summary_RealWage_NoE_L);

% By Market Potential
summary_Change_OnlineShare_E_M=summary_OnlineShare_E_M-summary_OnlineShare_NoE_M;
summary_Change_ImportRatio_E_M=summary_ImportRatio_E_M-summary_ImportRatio_NoE_M;
summary_Change_ImportRatioOnline_E_M=summary_ImportRatioOnline_E_M-summary_ImportRatioOnline_NoE_M;
summary_Change_ImportRatioOffline_E_M=summary_ImportRatioOffline_E_M-summary_ImportRatioOffline_NoE_M;
summary_Change_RealWage_E_M=log(summary_RealWage_E_M)-log(summary_RealWage_NoE_M);

disp([' Average Percentage Gains from E Commerce = ',num2str(mean(log(ECommEqm.RealWage)-log(NoECommEqm.RealWage)))])

%% Tabulating Results
% Table 9
fprintf('  Table 9. Panel A             Quintile of City Population               \n')
fprintf('                   Variable     1st      2nd      3rd      4th      5th        \n')
fprintf('                  Online Share')
fprintf('%8.4f %8.4f %8.4f %8.4f %8.4f \n',...
[summary_Change_OnlineShare_E_L])
fprintf('                  Import Ratio')
fprintf('%8.4f %8.4f %8.4f %8.4f %8.4f \n',...
[summary_Change_ImportRatio_E_L])
fprintf('                       Online ')
fprintf('%8.4f %8.4f %8.4f %8.4f %8.4f \n',...
[summary_Change_ImportRatioOnline_E_L])
fprintf('                       Offline')
fprintf('%8.4f %8.4f %8.4f %8.4f %8.4f \n',...
[summary_Change_ImportRatioOffline_E_L])
fprintf('                     Real Wage')
fprintf('%8.4f %8.4f %8.4f %8.4f %8.4f \n',...
[summary_Change_RealWage_E_L])
fprintf(' Table 9. Panel B        Quintile of City Market Potential             \n')
fprintf('                   Variable     1st      2nd      3rd      4th      5th        \n')
fprintf('                  Online Share')
fprintf('%8.4f %8.4f %8.4f %8.4f %8.4f  \n',...
[summary_Change_OnlineShare_E_M])
fprintf('                  Import Ratio')
fprintf('%8.4f %8.4f %8.4f %8.4f %8.4f  \n',...
[summary_Change_ImportRatio_E_M])
fprintf('                       Online ')
fprintf('%8.4f %8.4f %8.4f %8.4f %8.4f  \n',...
[summary_Change_ImportRatioOnline_E_M])
fprintf('                       Offline')
fprintf('%8.4f %8.4f %8.4f %8.4f %8.4f  \n',...
[summary_Change_ImportRatioOffline_E_M])
fprintf('                     Real Wage')
fprintf('%8.4f %8.4f %8.4f %8.4f %8.4f  \n',...
[summary_Change_RealWage_E_M])


%% Section 5.8: ACR Formula
sigmaACR=5;
WelfareGains_ACR=((1-ECommEqm.OnlineShare_by_City).^(1/(1-sigmaACR))).^(beta(:,2))-1;
%Figure 5
figure;
hold on
scatter(log(L),(log(ECommEqm.RealWage)-log(NoECommEqm.RealWage))*100,'o','filled')
scatter(log(L),WelfareGains_ACR*100,'xr')
hlines = lsline;
set(hlines(1), 'Color', 'r','linewidth',1)
set(hlines(2), 'Color', 'b','linewidth',2)
hold off
xlabel('log population')
ylabel('% Welfare Gains from e-Commerce')
xlim([12,17.5])
xticks(12:1:17)
ylim([0,4])
legend('Baseline Model','ACR (\sigma=5)')
saveas(gcf,'Figures/Figure5.png','png')


%% Appendix B: Further Development in e-Commerce
ScaleFactor=0.7819;
log_tau_E_MoreEcomm=log(ScaleFactor)+log_tau_E_2013;
tau_E_MoreEcomm=max(exp(log_tau_E_MoreEcomm),1);
MyTradeCostsMoreE=Func_v2struct(tau_E_MoreEcomm, tau_P, FixedCost);

disp('  Further Development in e-Commerce' )
MoreECommEqm=Func_Solve_The_Model_v0(MainParameters,MyTradeCostsMoreE,MainOptions);
disp([' Average Percentage Gains from Further E-Commerce Development = ',num2str(mean(MoreECommEqm.RealWage./NoECommEqm.RealWage-1))])

% Figure 6a
figure;
hold on
scatter(log(L),(log(ECommEqm.RealWage)-log(NoECommEqm.RealWage))*100,'o','filled')
scatter(log(L),(log(MoreECommEqm.RealWage)-log(NoECommEqm.RealWage))*100,'r')
hlines = lsline;
set(hlines(1), 'Color', 'r','linestyle','--','linewidth',1)
set(hlines(2), 'Color', 'b','linewidth',1)
hold off
xlim([12,17.5])
xticks(12:1:17)
xlabel('log population')
ylabel('% cumulative welfare gains from e-commerce')      
ylim([0,15])
legend('Benchmark','Further Development')
saveas(gcf,'Figures/Figure6a.png','png')

%Figure 6b
figure;
hold on
scatter(log(MarketPotential),(log(ECommEqm.RealWage)-log(NoECommEqm.RealWage))*100,'o','filled')
scatter(log(MarketPotential),(log(MoreECommEqm.RealWage)-log(NoECommEqm.RealWage))*100,'r')
hlines = lsline;
set(hlines(1), 'Color', 'r','linestyle','--','linewidth',1)
set(hlines(2), 'Color', 'b','linewidth',1)
hold off
xlabel('log market potential')
ylabel('% cumulative welfare gains from e-commerce')         
ylim([0,15])
legend('Benchmark','Further Development')
saveas(gcf,'Figures/Figure6b.png','png')

%% Exporting Data for Regression Analysis in STATA For Table 10.
OnlineShare0=NoECommEqm.OnlineShare_by_City;
ImportRatio0=NoECommEqm.ImportRatio;
ImportRatioOnline0=NoECommEqm.ImportRatioOnline;
ImportRatioOffline0=NoECommEqm.ImportRatioOffline;
RealWage0=NoECommEqm.RealWage;

OnlineShareBenchmark=ECommEqm.OnlineShare_by_City;
ImportRatioBenchmark=ECommEqm.ImportRatio;
ImportRatioOnlineBenchmark=ECommEqm.ImportRatioOnline;
ImportRatioOfflineBenchmark=ECommEqm.ImportRatioOffline;
RealWageBenchmark=ECommEqm.RealWage;

DataTable=table(L,MarketPotential,RealWage0,RealWageBenchmark);
writetable(DataTable,'Data_for_Table10.csv','Delimiter',',')
