%% "The Alibaba Effect: Spatial Consumption Inequality and Welfare Gains from E-commerce,"
% Fan, Tang, Zhu and Zou 2018
% This program produces Figures 3 and 4.
%% House Keeping: Managing Directory Paths
restoredefaultpath;
currentpath=pwd;
datapath=fullfile(currentpath,'Data');
estimatepath=fullfile(currentpath,'Estimates');
initialvaluepath=fullfile(currentpath,'InitialValues');
addpath(datapath);
addpath(estimatepath);
addpath(initialvaluepath);

%% Setting Parameter Values
%Load Data
load 'L.mat';
load 'SameProv.mat';
load 'data_service_share.mat';
load 'ProvGroup.mat';
load 'phi_min_v0.mat'
load 'BilateralDistance.mat';
load 'MainOptions.mat'

% Key Parameters
N=320    ; %Number of regions
H=2      ; %Number of sectors; h=1 is the nontradeable sector.
sigma=[5,5];
theta=[6,6]; 
beta=[data_service_share,(1-data_service_share)];
alpha=1.3*(sigma-1); % Pareto Shape parameter.
EntryCost=14.286;
kappa=gamma((theta+1-sigma)/theta).*(sigma./(sigma-1)).^(1-sigma); % Kappa is the constant defined in the text. Notice that gamma is a Matlab built-in function  
NProv=max(ProvGroup);    
MainParameters=Func_v2struct(N, NProv, ProvGroup,SameProv, L, H, beta, sigma, theta, kappa, alpha, phi_min, EntryCost);
parameter_file=fullfile(currentpath,'Data','MainParameters.mat');
save(parameter_file,'MainParameters')
[N, NProv, ProvGroup,SameProv, L, H, beta, sigma, theta, kappa, alpha, phi_min, EntryCost]=Func_v2struct(MainParameters);

%% Loading Trade Costs and EComm Costs Estimates
load 'calibrated_parameters.mat';
cost_vec=Cost_Vector;
FixedCost=exp(cost_vec(1));
Coef_0_P=cost_vec(2);
Coef_L_P=cost_vec(3);
Coef_Distance_P=cost_vec(4);
Coef_0_E=cost_vec(5);
Coef_DifCity_E=cost_vec(6);
Coef_Distance_E=cost_vec(7);
log_tau_P=Coef_0_P*(ones(N,N)-eye(N))+Coef_L_P*(ones(N,1)*log(L/min(L))')+Coef_Distance_P*log(BilateralDistance);
tau_P=exp(log_tau_P);
tau_P=max(tau_P, 1);
tau_E_2002=exp(50)*ones(N,N); % Setting E-Commerce Cost to be very high.
MyTradeCosts2002=Func_v2struct(tau_E_2002, tau_P, FixedCost);
log_tau_E_2013=Coef_0_E+(ones(N,N)-eye(N))*Coef_DifCity_E+Coef_Distance_E*log(BilateralDistance);
tau_E_2013=exp(log_tau_E_2013);
tau_E_2013=max(tau_E_2013,1);
MyTradeCosts2013=Func_v2struct(tau_E_2013, tau_P, FixedCost);
%% Solving the model with the different e-Commerce levels.
disp('-----------------------------' )
disp('  Economy without ECommerce  ' )
NoECommEqm=Func_Solve_The_Model_v0(MainParameters,MyTradeCosts2002,MainOptions);
disp('-----------------------------' )
disp('  Economy with ECommerce     ' )
ECommEqm=Func_Solve_The_Model_v0(MainParameters,MyTradeCosts2013,MainOptions);

%% Changes Across Equilibrium
ChangeRealWage=ECommEqm.RealWage./NoECommEqm.RealWage-1;
ChangeNominalWage=ECommEqm.NominalWage./NoECommEqm.NominalWage-1;
ChangePriceIndex=ECommEqm.PriceIndex./NoECommEqm.PriceIndex-1;

%Figure 3
% Change in Nominal Wage
figure;
hold on
scatter(log(L),ChangeNominalWage, 20,'filled')
hlines = lsline;
set(hlines(1), 'Color', 'b','linewidth',2)
hold off
xlim([12,17.5])
ylim([-0.025,0.025])
xticks(12:1:17)
yticks(-0.02:0.01:0.02)
xlabel('log population')
ylabel('% Change in Nominal Wage (Total GDP normalized to 1)') 
saveas(gcf,'Figures/Figure3a.png','png')

% Change in Price Index
figure;
hold on
scatter(log(L),ChangePriceIndex,20,'filled')
hlines = lsline;
set(hlines(1), 'Color', 'b','linewidth',2)
hold off
xlim([12,17.5])
ylim([-0.025,0.025])
xticks(12:1:17)
yticks(-0.02:0.01:0.02)
xlabel('log population')
ylabel('% Change in Price Index (Total GDP normalized to 1)') 
saveas(gcf,'Figures/Figure3b.png','png')

%% Labor Decomposition
TotalLaborCost=(NoECommEqm.LaborFixedCost+NoECommEqm.LaborVariableCost+NoECommEqm.LaborEntryCost);
ChangeLaborFixedCost=(ECommEqm.LaborFixedCost-NoECommEqm.LaborFixedCost)./TotalLaborCost;
ChangeLaborVariableCost=(ECommEqm.LaborVariableCost-NoECommEqm.LaborVariableCost)./TotalLaborCost;
ChangeLaborEntryCost=(ECommEqm.LaborEntryCost-NoECommEqm.LaborEntryCost)./TotalLaborCost;

%% Decomposition of Price Index
%This comparison is by fixing the productivity cutoff to be the same as
%before e-Commerce
phi_off_NoE=NoECommEqm.phi_off;
FirmMassT_NoE=NoECommEqm.FirmMass(:,2);
TempTermON_NoE=tau_E_2002.^(1-sigma(2)).*((phi_min(:,2)*ones(1,N)).^alpha(2).*phi_off_NoE.^(sigma(2)-alpha(2)-1)-(phi_min(:,2)*ones(1,N)).^(sigma(2)-1)); % Online-Only Firm
TempTermTC_NoE=-(tau_P.^(-theta(2))+tau_E_2002.^(-theta(2))).^(-(1-sigma(2))/theta(2)).*((phi_min(:,2)*ones(1,N)).^alpha(2).*phi_off_NoE.^(sigma(2)-alpha(2)-1)); % Two-Channel Firm
PsiMatrix_NoE_PartON=(kappa(2)*alpha(2)/(sigma(2)-alpha(2)-1))*TempTermON_NoE'.* (ones(N,1)*(NoECommEqm.NominalWage'.^(1-sigma(2))));
PsiMatrix_NoE_PartTC=(kappa(2)*alpha(2)/(sigma(2)-alpha(2)-1))*TempTermTC_NoE'.* (ones(N,1)*(NoECommEqm.NominalWage'.^(1-sigma(2))));
PsiMatrix_NoE=PsiMatrix_NoE_PartON+PsiMatrix_NoE_PartTC;
P_power_T_PartON_NoE=PsiMatrix_NoE_PartON*FirmMassT_NoE;
P_power_T_PartTC_NoE=PsiMatrix_NoE_PartTC*FirmMassT_NoE;

% E
FirmMassT_E=ECommEqm.FirmMass(:,2);
TempTermON_E=tau_E_2013.^(1-sigma(2)).*((phi_min(:,2)*ones(1,N)).^alpha(2).*phi_off_NoE.^(sigma(2)-alpha(2)-1)-(phi_min(:,2)*ones(1,N)).^(sigma(2)-1)); % Online-Only Firm
TempTermTC_E=-(tau_P.^(-theta(2))+tau_E_2013.^(-theta(2))).^(-(1-sigma(2))/theta(2)).*((phi_min(:,2)*ones(1,N)).^alpha(2).*phi_off_NoE.^(sigma(2)-alpha(2)-1)); % Two-Channel Firm
PsiMatrix_E_PartON=(kappa(2)*alpha(2)/(sigma(2)-alpha(2)-1))*TempTermON_E'.* (ones(N,1)*(ECommEqm.NominalWage'.^(1-sigma(2))));
PsiMatrix_E_PartTC=(kappa(2)*alpha(2)/(sigma(2)-alpha(2)-1))*TempTermTC_E'.* (ones(N,1)*(ECommEqm.NominalWage'.^(1-sigma(2))));
PsiMatrix_E=PsiMatrix_E_PartON+PsiMatrix_E_PartTC;
P_power_T_PartON_E=PsiMatrix_E_PartON*FirmMassT_NoE;
P_power_T_PartTC_E=PsiMatrix_E_PartTC*FirmMassT_NoE;

P_power_T_NoE=NoECommEqm.P_power(:,2);
P_power_T_E=ECommEqm.P_power(:,2);

phi_off_E=ECommEqm.phi_off;
TempTermON_2A=tau_E_2013.^(1-sigma(2)).*((phi_min(:,2)*ones(1,N)).^alpha(2).*phi_off_NoE.^(sigma(2)-alpha(2)-1)-(phi_min(:,2)*ones(1,N)).^(sigma(2)-1)); % Online-Only Firm using NEW TC CUTOFF
TempTermTC_2A=-(tau_P.^(-theta(2))+tau_E_2013.^(-theta(2))).^(-(1-sigma(2))/theta(2)).*((phi_min(:,2)*ones(1,N)).^alpha(2).*phi_off_NoE.^(sigma(2)-alpha(2)-1)); % Two-Channel Firm using NEW TC CUTOFF
TempTermON_2B=tau_E_2013.^(1-sigma(2)).*((phi_min(:,2)*ones(1,N)).^alpha(2).*phi_off_E.^(sigma(2)-alpha(2)-1)-(phi_min(:,2)*ones(1,N)).^(sigma(2)-1)); % Online-Only Firm using NEW TC CUTOFF
TempTermTC_2B=-(tau_P.^(-theta(2))+tau_E_2013.^(-theta(2))).^(-(1-sigma(2))/theta(2)).*((phi_min(:,2)*ones(1,N)).^alpha(2).*phi_off_E.^(sigma(2)-alpha(2)-1)); % Two-Channel Firm using NEW TC CUTOFF
TempTerm= kappa(2)* (TempTermON_2B+TempTermTC_2B-TempTermON_2A-TempTermTC_2A)'.* (ones(N,1)*(ECommEqm.NominalWage'.^(1-sigma(2))))*alpha(2)/(sigma(2)-alpha(2)-1)*FirmMassT_NoE; % The component due to reallocation effects
ChangeOthersPart1=1/(1-sigma(2))*TempTerm./P_power_T_NoE;     % First part of Residual Effect

ChangeNewEntrants=1/(1-sigma(2))*PsiMatrix_NoE*(FirmMassT_E-FirmMassT_NoE)./P_power_T_NoE; % New Entrants Effect
ChangePartON=1/(1-sigma(2))*(P_power_T_PartON_E-P_power_T_PartON_NoE)./P_power_T_NoE; % Variety Effect
ChangePartTC=1/(1-sigma(2))*(P_power_T_PartTC_E-P_power_T_PartTC_NoE)./P_power_T_NoE; % Price Effect
ChangeOthersPart2=1/(1-sigma(2))*(PsiMatrix_E-PsiMatrix_NoE)*(FirmMassT_E-FirmMassT_NoE)./P_power_T_NoE; % Second part of Residual Effect
ChangeOthers=ChangeOthersPart1+ChangeOthersPart2; % Residual Effect
%% Figure 4
figure;
hold on
scatter(log(L),ChangeLaborVariableCost*100, 20,'om')
scatter(log(L),ChangeLaborFixedCost*100,15,'db')
scatter(log(L),ChangeLaborEntryCost*100,10,'xk')
hlines = lsline;
set(hlines(1), 'Color', 'k','linewidth',2)
set(hlines(2), 'Color', 'b','linewidth',1)
set(hlines(3), 'Color', 'm','linewidth',1)
legend('Production Labor','Fixed Cost','Entry Cost')
hold off
xlim([12,17.5])
xticks(12:1:17)
xlabel('log population')
ylabel('Change in Composition of Labor Demand') 
saveas(gcf,'Figures/Figure4a.png','png')

figure;
hold on
scatter(log(L),ChangePartON,10,'or','filled')
scatter(log(L),ChangePartTC,'xm')
scatter(log(L),ChangeNewEntrants,10,'db')
scatter(log(L),ChangeOthers,20,'xk')
hlines = lsline;
set(hlines(4), 'Color', 'r','linewidth',0.5,'linestyle','--')
set(hlines(3), 'Color', 'm','linewidth',2)
set(hlines(2), 'Color', 'b','linewidth',1)
set(hlines(1), 'Color', 'k','linewidth',0.5,'linestyle','--')
hold off
xlim([12,17.5])
xticks(12:1:17)
xlabel('log population')
ylabel('% Change in Price Index in Tradeable Sector')
legend('Variety Effect','Price Effect','New Entrants Effect','Residual Effects')
saveas(gcf,'Figures/Figure4b.png','png')

% END