%% "The Alibaba Effect: Spatial Consumption Inequality and Welfare Gains from E-commerce,"
% Fan, Tang, Zhu and Zou 2018
% This program produces the column for (sigma=5, theta=7) of Tables D6, D7 and D8. 
%% House Keeping: managing Directory Paths
restoredefaultpath;
currentpath=pwd;
datapath=fullfile(currentpath,'Data');
estimatepath=fullfile(currentpath,'Estimates');
initialvaluepath=fullfile(currentpath,'InitialValues');
addpath(datapath);
addpath(estimatepath);
addpath(initialvaluepath);
%% Setting Parameter Values, to be stored in a structure
load 'L.mat';
load 'SameProv.mat';
load 'data_service_share.mat';
load 'ProvGroup.mat';
load 'phi_min_theta7.mat'
load 'BilateralDistance.mat';

% Key Parameters
N=320    ; %Number of regions
H=2      ; %Number of sectors; h=1 is the nontradeable sector.
sigma=[5,5];
theta=[7,7]; 
beta=[data_service_share,(1-data_service_share)];
alpha=1.3*(sigma-1); % Pareto Shape parameter.
EntryCost=14.243; %Entry Cost Parameter
kappa=gamma((theta+1-sigma)/theta).*(sigma./(sigma-1)).^(1-sigma); % Kappa is the constant defined in the text. Notice that gamma is a Matlab built-in function  
NProv=max(ProvGroup);       % Number of Provinces
MainParameters=Func_v2struct(N, NProv, ProvGroup,SameProv, L, H, beta, sigma, theta, kappa, alpha, phi_min, EntryCost);
Main_parameter_file=fullfile(currentpath,'Data','MainParameters.mat');
save(Main_parameter_file,'MainParameters')

%% Stepsize and Convergence Criteria, to be stored in a structure. 
StepsizeWage=0.2;
StepsizeP=0.5;
StepsizeM=0.15;
Max_P_Iter=30000;
ToleranceExcessProfit=1e-6;
ToleranceL=1e-6;
ToleranceP=1e-5;

FirmMass_ini=beta.*[L,L]/40;
w_autarky=ones(N,1); 
P_power_autarky=-((ones(N,1)*(kappa.*alpha)).*phi_min.^(ones(N,1)*(sigma-1))./(ones(N,1)*(sigma-alpha-1))).*(FirmMass_ini.*(w_autarky*ones(1,H)).^(ones(N,1)*(1-sigma))); %From zero profit condition
w_ini=w_autarky;
P_power_ini=P_power_autarky;

MainOptions=Func_v2struct(ToleranceExcessProfit, ToleranceL, ToleranceP,StepsizeWage,StepsizeP,StepsizeM,Max_P_Iter,w_ini,P_power_ini,FirmMass_ini);
Main_option_file=fullfile(currentpath,'Data','MainOptions.mat');
save(Main_option_file,'MainOptions')

%% Target Moments from the data
DataAverageFirmSize=80;
DataExporterPercentage2002=0.94; % Notice that previously that we use 74% as share of firms selling offline to another Province. The current figure is to another CITY.
DataProvAbsorptionRatio2013=0.54; % Province Absorption Ratio 
DataProvAbsorptionRatioOnline2013=0.145; % Online Province Absorption Ratio
DataOfflineElasticity2002=-1.40; 
DataOnlineElasticity2013=-0.47; 
DataCoef_L_OnlineShare2013=-0.11;
DataCoef_MP_OnlineShare2013=-0.19;
DataOnlineShare2013=0.080;
CalibrationTargets=Func_v2struct(DataAverageFirmSize,DataExporterPercentage2002,DataProvAbsorptionRatio2013,DataProvAbsorptionRatioOnline2013,DataOfflineElasticity2002,DataOnlineElasticity2013,DataCoef_L_OnlineShare2013,DataCoef_MP_OnlineShare2013,DataOnlineShare2013);
CalibrationTargets_file=fullfile(currentpath,'Data','CalibrationTargets.mat');
save(CalibrationTargets_file,'CalibrationTargets')

%% Step 1. Calibrate
CostVec_ini=[-2.4597,-0.33212,0.071934,0.21583,0.80198,0.24052,0.1171];
test_value= Func_SolvingTwoEqm(CostVec_ini);
tstart=tic; 
options = optimset('Display','iter','MaxFunEvals',2000,'MaxIter',2000);
[Cost_Vector,~,ExitFlagStep1] = fminsearch(@Func_SolvingTwoEqm, CostVec_ini,options);
TimeTaken=toc(tstart)/60;
disp([' Time Taken  : ', num2str(floor(TimeTaken/60)), ' hours and ', num2str(mod(TimeTaken,60)), ' minutes.']);
calibrated_parameters_file=fullfile(currentpath,'Estimates','calibrated_parameters_Theta7.mat');
save(calibrated_parameters_file,'Cost_Vector');

%%
load 'calibrated_parameters_Theta7.mat';
cost_vec=Cost_Vector;
FixedCost=exp(cost_vec(1));
Coef_0_P=cost_vec(2);
Coef_L_P=cost_vec(3);
Coef_Distance_P=cost_vec(4);
Coef_0_E=cost_vec(5);
Coef_DifCity_E=cost_vec(6);
Coef_Distance_E=cost_vec(7);

log_tau_P=Coef_0_P*(ones(N,N)-eye(N))+Coef_L_P*(ones(N,1)*log(L/min(L))')+Coef_Distance_P*log(BilateralDistance);
tau_P=exp(log_tau_P);
tau_P=max(tau_P, 1);

tau_E_2002=exp(50)*ones(N,N); % Setting E-Commerce Cost to be very high.
MyTradeCosts2002=Func_v2struct(tau_E_2002, tau_P, FixedCost);
log_tau_E_2013=Coef_0_E+(ones(N,N)-eye(N))*Coef_DifCity_E+Coef_Distance_E*log(BilateralDistance);
tau_E_2013=exp(log_tau_E_2013);
tau_E_2013=max(tau_E_2013,1);
MyTradeCosts2013=Func_v2struct(tau_E_2013, tau_P, FixedCost);
MarketPotential=(1./BilateralDistance)*L-(L./diag(BilateralDistance)); %Measure of Market Potential
%% Solving the model with the different e-Commerce levels.
disp('-----------------------------' )
disp('  Economy without ECommerce  ' )
NoECommEqm=Func_Solve_The_Model_v0(MainParameters,MyTradeCosts2002,MainOptions);
disp('-----------------------------' )
disp('  Economy with ECommerce     ' )
ECommEqm=Func_Solve_The_Model_v0(MainParameters,MyTradeCosts2013,MainOptions);
%% Tabulating the Effects of e-Commerce
RealWage_by_size_half_M=Func_Summarize_By_Half(NoECommEqm.RealWage,MarketPotential); %summarize
norm_RealWage_M=RealWage_by_size_half_M(1); %getting a number for the normalization. 
RealWage_by_size_half_L=Func_Summarize_By_Half(NoECommEqm.RealWage,L); %summarize
norm_RealWage_L=RealWage_by_size_half_L(1); %getting a number for the normalization. 
% No E
summary_RealWage_NoE_L=Func_Summarize_By_Half(NoECommEqm.RealWage/norm_RealWage_L,L);
summary_RealWage_NoE_M=Func_Summarize_By_Half(NoECommEqm.RealWage/norm_RealWage_M,MarketPotential);
% E
summary_RealWage_E_L=Func_Summarize_By_Half(ECommEqm.RealWage/norm_RealWage_L,L);
summary_RealWage_E_M=Func_Summarize_By_Half(ECommEqm.RealWage/norm_RealWage_M,MarketPotential);
% Changes
% By Population
summary_Change_RealWage_E_L=log(summary_RealWage_E_L)-log(summary_RealWage_NoE_L);
% By Market Potential
summary_Change_RealWage_E_M=log(summary_RealWage_E_M)-log(summary_RealWage_NoE_M);

%% Tables 6,7,8
disp(' Column (sigma=5, theta=7) of Table D6 ')
func= Func_SolvingTwoEqm(Cost_Vector);

% Column 5 of Table D7
delta0=0;
delta1=Coef_0_P+Coef_Distance_P*log(100); % Normalization by which we measure bilateral distance in unit of 100 kms.
delta2=Coef_Distance_P;
deltaL=Coef_L_P;
gamma0=Coef_0_E;
gamma1=Coef_0_E+Coef_DifCity_E+Coef_Distance_E*log(100);  % Normalization by which we measure bilateral distance in unit of 100 kms.
gamma2=Coef_Distance_E;
disp(' Column 5 of Table D7 ')
disp(['     entry cost=     ',num2str(EntryCost(1))])
disp(['     fixed cost=     ',num2str(FixedCost(1))])
disp(['        delta_0=     ',num2str(delta0)])
disp(['        delta_1=     ',num2str(delta1)])
disp(['        delta_2=     ',num2str(delta2)])
disp(['        delta_L=     ',num2str(deltaL)])
disp(['        gamma_0=     ',num2str(gamma0)])
disp(['        gamma_1=     ',num2str(gamma1)])
disp(['        gamma_2=     ',num2str(gamma2)])

% Column 5 of Table D8
fprintf('----------------------------------------------------------- \n');
fprintf(' Column 5 of Table D8                   \n');
fprintf(' The Effect of E-Commerce on  Real Wage \n');
fprintf('      Change                         Quintile of City Population      Quintile of City Market Potential     \n')
fprintf('                   Variable          Above Median    Below Median      Above Median    Below Median          \n')
fprintf('                     Real Wage')
fprintf('%15.4f %15.4f %15.4f %15.4f \n',...
[summary_Change_RealWage_E_L,summary_Change_RealWage_E_M])
% END
