/***********************************/
/*** Empirics.do				 ***/
/*** Replication codes for reduced-form results ***/
/***********************************/
clear all
set more off
clear all
set mem 1g


/*** PART I: Province-province trade flows ***/
/*** log online flow (adjusted by adding a normal noise term with s.e. of 2.5) ***/
use GravitySample.dta, clear

areg ln_online_flow_adj ln_dist i.source_id, a(destination_id) robust
eststo Tbl1_1
areg ln_offline_flow ln_dist i.source_id, a(destination_id) robust
eststo Tbl1_2

esttab Tbl1_*, title(province by UHS catgory) keep(ln_dist) mtitle(online offline) se stats(N r2) label


/*** PART II: City-Cateogry Level ***/
/*** Online shares imputed based on Tbl 3 Col 2 ***/

/***********************************/
/*** Table 2: Summary Stats		 ***/
/***
	NOTE:
	Online shares are imputed
	OnlineRetailer: online sales as a share of total retail sales
	OnlineoverAverageConsumption: online sales as a share of consumption
	OnlineNonRestaurantRetail: online sales as a share of non-hospitality retail sales
***/
/***********************************/
use CitySample.dta, clear

gen OnlineRetailer = exp(ln_OnlineRetailer)
gen OnlineoverAverageConsumption = exp(ln_OnlineoverAverageConsumption)
gen OnlineNonRestaurantRetail = exp(ln_OnlineNonRestaurantRetail)
gen pop10 = exp(lnPop_10)/1E6
gen OMP = exp(ln_OMP)/1E9
gen internetPenetration = exp(ln_internetPenetration)
gen AverageIncome = exp(ln_AverageIncome)/1E3
gen avg_schl_yr = exp(ln_avg_schl_yr)
gen NonAgr_Emp_Share10 = exp(ln_NonAgr_Emp_Share10)/100
	

# delimit ;
ds 	OnlineRetailer 
	pop10 OMP

	/* demand shifters */
	AverageIncome avg_schl_yr NonAgr_Emp_Share10 
	share_15to64 sexratio_0to14
	
	/* supply shifters */
	ln_road ln_rail  internetPenetration ln_OnlineMP ProvCapital 	
	
	/* alternative Y*/
	OnlineoverAverageConsumption
	OnlineNonRestaurantRetail
	
	/* alternative X*/
	TotalIncome
	TotalConsumption
	
	ln_OMA
	ln_MP_GDP
;
# delimit cr
local varlist `r(varlist)'
local wc: word count `varlist'


mat B = J(`wc',5,.)
mat colnames B = N mean sd p10 p90
mat rownames B = `varlist'

local n = 1
foreach var of local varlist {
	qui summ `var',de
	mat B[`n',1] = round(`r(N)', 0.001)
	mat B[`n',2] = round(`r(mean)', 0.001)
	mat B[`n',3] = round(`r(sd)', 0.001)
	mat B[`n',4] = round(`r(p10)', 0.001) 
	mat B[`n',5] = round(`r(p90)', 0.001)
	
	local n = `n' + 1
}

matlist B


/***********************************/
/*** Table 3: Online Expenditure Share and Market Size		 ***/
/***********************************/
eststo clear 

/* 1. No Covariate */
local covlist1 ""

/* 2. provincial capital */
local covlist2 "ProvCapital"

/* 3. road connectivity*/
local covlist3 "`covlist2' ln_road ln_rail"

/* 4. internet connectivity */
local covlist4 "`covlist2' ln_internetPenetration"

/* 5. Mkt Access */
local covlist5 "`covlist2' ln_OnlineMP"

/* 6. All */
local covlist6 "ProvCapital ln_road ln_rail ln_internetPenetration ln_OnlineMP"
dis  "`covlist6'"

/* 7. All + prov FE */
local covlist7 "`covlist6' i.prov_id"

forvalues i = 1/7 {
	qui xi: reg ln_OnlineRetailer lnPop_10 ln_OMP `covlist`i'', robust
	eststo Tbl3_`i'
}

# delimit ;
esttab Tbl3*,
 	b(3) se(3)
	drop(*prov_id*)
	star(* 0.1 ** 0.05 *** 0.01)
	title("Online Expenditure Share and Market Size")
	mtitle(ret ret ret ret ret ret_ALL ret_Prov)	
	se stats(N r2)
	label
	modelwidth(8)
	addnote("Note: Online share imputed to match coefficients in Col. 2")
;
# delimit cr



/***********************************/
/*** Table 4: Adding Demand Shifters***/
/***********************************/
/* Demand Controls */
/* 1. Local basics: average income */
local demlist1 "ln_AverageIncome"

/* 2. Local basics: demographics */
local demlist2 "ln_avg_schl_yr"

/* 3. Local basics: non-agr emp share */
local demlist3 "ln_NonAgr_Emp_Share10"

/* 4. Age and gender */
* local demlist4 "share_15to64 sexratio_0to14 share_minority"
local demlist4 "share_15to64 sexratio_0to14"

/* 5. All */
local demlist5 "`demlist1' `demlist2' `demlist3' `demlist4'"


forvalues i = 1/5 {
	qui xi: reg ln_OnlineRetailer lnPop_10 ln_OMP `covlist7' `demlist`i'', robust
	eststo Tbl4_`i'
}


qui xi: reg ln_OnlineRetailer lnPop_10 `covlist7' `demlist5', robust
eststo Tbl4_6
qui xi: reg ln_OnlineRetailer ln_OMP `covlist7' `demlist5', robust
eststo Tbl4_7


# delimit ;
esttab Tbl4_*,
	se(3) b(3)
	drop(*prov_id*)
	star(* 0.1 ** 0.05 *** 0.01)
	title("Adding Demand Shifters")
	se stats(N r2)
	label nomtitles
	modelwidth(8)
;
# delimit cr


/*** PART III: City-by-Category Level ***/
/*** a normal disturbance with variance of 1/2 is added to the outcome variable. ***/

/***********************************/
/*** Table 5: City by Category	 ***/
/*** city-by-category online share imputed. ***/
/***********************************/
use CityCatSample.dta, clear

merge m:1 Region_4d using CitySample.dta
keep if _merge == 3
drop _merge

local demlist "ln_AverageIncome ln_avg_schl_yr ln_NonAgr_Emp_Share10 share_15to64 sexratio_0to14"
local supplist "ln_road ln_rail ln_internetPenetration ProvCapital ln_OnlineMP"


eststo clear
forvalues i = 1/7 {
	qui xi: reg ln_OnlineRetailer_adj lnPop_10 ln_OMP `supplist' `demlist' i.prov_id if UHS_Cat == `i', robust
	eststo Tbl5_`i'
	qui summ ln_OnlineRetailer_adj if e(sample) == 1
	estadd scalar dep_mean = exp(`r(mean)') * 100

}


/*** display table  ***/
# delimit ;
esttab Tbl5*,
	drop(*prov*) 
	star(* 0.1 ** 0.05 *** 0.01)
	title(province by UHS catgory)
	mtitle(food cloth residence hhd_appliance health trans recreation)
	se stats(N r2 dep_mean)
	label
;
# delimit cr




* end




